# v1.0.2

Feature improvements and bug fixes.

- Resolve actual struct type names instead of showing "ExtensionObject" for complex types
- Always attempt value reads for complex types, with graceful fallback
- Display decoded struct fields in the detail panel
- Connection page now continuously scans for servers every 5 seconds
- Updated README for optional native window
- Fixed release script to use `python3`
